# Cats core

Cats core is a Python library for [cats project](https://finance.rescala.jp/?page_id=204).

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install catscore
```

## Usage

```python
tbd = "TBD
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)

## Mecab installation
If you are failing to install mecab-python3, please check it

en:  https://github.com/shogun-toolbox/shogun/issues/2930
jp: https://qiita.com/siraasagi/items/e07e0b271cb7cd679a70

### Swig problem at mecab-python

You need to update swig > 0.3.8
Please execute yum install swig3